%  ufrint: interpolation via fractional fourier transform
% 	y = ufrint(x,start,del)
%  Inputs
% 	x		dyadic sequence -- 1 by m = 2^integer
% 	start   starting sample of interpolation
% 	d		interval between samples
%  Outputs
% 	y	interpolated data -- 1 by m.
%  Description
% 	Uses the fractional fft to interpolate
%  n = length(x) samples in between given samples
% 	Example
% 		y = ufrint(x,1,1)  -- the identity operator
% 		y = ufrint(x,1,.5) -- samples at midpoints,
% 		     1,1.5,2,2.5,....,n/2-.5
% 	Basic Idea:
%    1.	View data in x as representing X_t -n/2 <= t < n/2
% 		set s = start-1-n/2, i.e. subscript 1 -> t= -n/2
%    2.	Fit trigonometric polynomial
%       		X_t = T(t) ,
% 		where 
% 			T(t) = m^{-1} * 
%            Sum( tilde{X}_l exp(2*pi*i*l*t/m) : -n/2 <= l <= n/2 )
%    3.	Evaluate trigonometric polynomial
%         	T(s + j*del) for j=0, ... , m-1
% 		i.e. evaluate
% 		    Sum( tilde{X}_l exp(2*pi*i*l*(s+j*del)/m) : -n/2 <= l <= n/2 )
% 		for each j=0,...,m-1
%    4.	Use Fractional FT to do this, i.e. write this sum as
%            Sum( tilde{X}_k^{(s)} exp(2*pi*i*k*(j*del)/m) : 0 <= k <= n )
%            * exp(-i*pi*j*del )
% 		The sum has the form of a fractional FT except that it ranges
% 		over n+1 terms.  Take the last term out and deal with it
% 		`by hand'.  Then the sum has the form of a fractional FT. 
% 
%
%
% Part of BeamLab Version:200
% Built:Friday,23-Aug-2002 00:00:00
% This is Copyrighted Material
% For Copying permissions see COPYING.m
% Comments? e-mail beamlab@stat.stanford.edu
%
%
% Part of BeamLab Version:200
% Built:Saturday,14-Sep-2002 00:00:00
% This is Copyrighted Material
% For Copying permissions see COPYING.m
% Comments? e-mail beamlab@stat.stanford.edu
%