function y = haarTIApprox1D(x,pen,noiseType);
if (nargin < 3)
  noiseType = 'Poisson';
end
if (nargin < 2)
  if strcmp(noiseType,'Poisson')
    pen = log(sum(x(:)))/2;
  else
    pen = log(prod(size(x)))/2;
  end
end

if (strcmp(noiseType,'Poisson') & any(isnan(x)))
  error('Invalid Poisson counts; check to make sure intensity non-negative.');
end
x_orig = x;
x = x(:);
[N] = length(x);
L = log2(N);

xScalingPrev = x;
y = x;

wavelet = zeros([N,L]);
splitDecision = zeros([N,L]);

optProb = logLike(x,x,noiseType)-pen;
if strcmp(noiseType,'Poisson')
  mergeProb = zeros(size(x));
else
  mergeProb = -x.^2;
end


for iL = 1:(L+1)
  dyadLen = 2^iL;
  % calculate current scaling coefficient
  xScaling = (xScalingPrev + circshift(xScalingPrev,[-dyadLen/2]))/2;

  % log probability of merging
  mergeSum = mergeProb+circshift(mergeProb,[-dyadLen/2]);
  if strcmp(noiseType,'Poisson')
    pMerge = mergeSum - ...
      (xScaling*dyadLen.*(1-log(xScaling*dyadLen+realmin)-log(0.5))).*(xScaling>0) - ...
      pen;
  else
    pMerge = mergeSum + xScaling.^2*dyadLen - pen;
  end

  % log probability of splitting
  pSplit = optProb+circshift(optProb,[-dyadLen/2]);
  
  % terms of merge log probability needed to calculated pMerge at next
  % scale
  if strcmp(noiseType,'Poisson')
    mergeProb = mergeSum + xScaling*dyadLen*log(0.5);
  else
    mergeProb = mergeSum;
  end
  
  % "wavelet" coefficients
  wavelet(:,iL) = xScalingPrev-xScaling;

  % decide whether to split or merge, save decision and associated log
  % probability
  splitDecision(:,iL) = (pSplit >= pMerge).*1;
  optProb = pSplit.*splitDecision(:,iL) + pMerge.*(1-splitDecision(:,iL));
  
  xScalingPrev = xScaling;
  
end

% initial estimate is coarse scale scaling coefficients 
y = xScaling;
waveletScale = ones(N,1);
waveletScaleNext = ones(N,1);

for iL = (L+1):-1:1
  dyadLen = 2^iL;
  % if the split decision is zero, then the associated wavelet should be set
  % to zero.
  waveletScale = waveletScale.*splitDecision(:,iL);
  
  if iL > 1
    waveletScaleNext = waveletScaleNext - (0.5*(1.0-waveletScale));
    waveletScaleNext = circshift(circshift(waveletScaleNext,[-dyadLen/2]) ...
      - (0.5*(1.0-waveletScale)),[dyadLen/2]);
  end
  
  % construct estimate based on wavelet coefficients and thresholds
  xD1 = (wavelet(:,iL)).*waveletScale;
  xD3 = circshift((wavelet(:,iL)).*waveletScale,[dyadLen/2]);

  xScaling = (y+xD1 + circshift(y,[dyadLen/2])-xD3 )/2;

  y = xScaling;
  waveletScale = waveletScaleNext;
  waveletScaleNext = ones(N,1);
end

y = reshape(y,size(x_orig));
return;
